# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.emr.v20190103 import models


class EmrClient(AbstractClient):
    _apiVersion = '2019-01-03'
    _endpoint = 'emr.tencentcloudapi.com'
    _service = 'emr'


    def AddUsersForUserManager(self, request):
        """该接口支持安装了OpenLdap组件的集群。
        新增用户列表（用户管理）。

        :param request: Request instance for AddUsersForUserManager.
        :type request: :class:`tencentcloud.emr.v20190103.models.AddUsersForUserManagerRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.AddUsersForUserManagerResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("AddUsersForUserManager", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.AddUsersForUserManagerResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateInstance(self, request):
        """创建EMR集群实例

        :param request: Request instance for CreateInstance.
        :type request: :class:`tencentcloud.emr.v20190103.models.CreateInstanceRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.CreateInstanceResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateInstance", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateInstanceResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeClusterNodes(self, request):
        """查询硬件节点信息

        :param request: Request instance for DescribeClusterNodes.
        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeClusterNodesRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeClusterNodesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeClusterNodes", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeClusterNodesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeCvmQuota(self, request):
        """获取账户的CVM配额

        :param request: Request instance for DescribeCvmQuota.
        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeCvmQuotaRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeCvmQuotaResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeCvmQuota", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeCvmQuotaResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeEmrApplicationStatics(self, request):
        """yarn application 统计接口查询

        :param request: Request instance for DescribeEmrApplicationStatics.
        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeEmrApplicationStaticsRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeEmrApplicationStaticsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeEmrApplicationStatics", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeEmrApplicationStaticsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeInstanceRenewNodes(self, request):
        """预付费集群隔离后续费资源查询

        :param request: Request instance for DescribeInstanceRenewNodes.
        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeInstanceRenewNodesRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeInstanceRenewNodesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeInstanceRenewNodes", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeInstanceRenewNodesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeInstances(self, request):
        """查询EMR实例

        :param request: Request instance for DescribeInstances.
        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeInstancesRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeInstancesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeInstances", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeInstancesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeInstancesList(self, request):
        """EMR集群实例列表查询

        :param request: Request instance for DescribeInstancesList.
        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeInstancesListRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeInstancesListResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeInstancesList", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeInstancesListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeJobFlow(self, request):
        """查询流程任务

        :param request: Request instance for DescribeJobFlow.
        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeJobFlowRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeJobFlowResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeJobFlow", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeJobFlowResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeResourceSchedule(self, request):
        """获取yarn资源调度页面的数据

        :param request: Request instance for DescribeResourceSchedule.
        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeResourceScheduleRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeResourceScheduleResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeResourceSchedule", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeResourceScheduleResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeUsersForUserManager(self, request):
        """该接口支持安装了OpenLdap组件的集群。
        批量导出用户。对于kerberos集群，如果需要kertab文件下载地址，可以将NeedKeytabInfo设置为true；注意SupportDownLoadKeyTab为true，但是DownLoadKeyTabUrl为空字符串，表示keytab文件在后台没有准备好（正在生成）。

        :param request: Request instance for DescribeUsersForUserManager.
        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeUsersForUserManagerRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeUsersForUserManagerResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeUsersForUserManager", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeUsersForUserManagerResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def InquirePriceRenewEmr(self, request):
        """集群续费询价。

        :param request: Request instance for InquirePriceRenewEmr.
        :type request: :class:`tencentcloud.emr.v20190103.models.InquirePriceRenewEmrRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.InquirePriceRenewEmrResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("InquirePriceRenewEmr", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.InquirePriceRenewEmrResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def InquiryPriceCreateInstance(self, request):
        """创建实例询价

        :param request: Request instance for InquiryPriceCreateInstance.
        :type request: :class:`tencentcloud.emr.v20190103.models.InquiryPriceCreateInstanceRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.InquiryPriceCreateInstanceResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("InquiryPriceCreateInstance", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.InquiryPriceCreateInstanceResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def InquiryPriceRenewInstance(self, request):
        """续费询价。

        :param request: Request instance for InquiryPriceRenewInstance.
        :type request: :class:`tencentcloud.emr.v20190103.models.InquiryPriceRenewInstanceRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.InquiryPriceRenewInstanceResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("InquiryPriceRenewInstance", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.InquiryPriceRenewInstanceResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def InquiryPriceScaleOutInstance(self, request):
        """扩容询价. 当扩容时候，请通过该接口查询价格。

        :param request: Request instance for InquiryPriceScaleOutInstance.
        :type request: :class:`tencentcloud.emr.v20190103.models.InquiryPriceScaleOutInstanceRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.InquiryPriceScaleOutInstanceResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("InquiryPriceScaleOutInstance", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.InquiryPriceScaleOutInstanceResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def InquiryPriceUpdateInstance(self, request):
        """变配询价

        :param request: Request instance for InquiryPriceUpdateInstance.
        :type request: :class:`tencentcloud.emr.v20190103.models.InquiryPriceUpdateInstanceRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.InquiryPriceUpdateInstanceResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("InquiryPriceUpdateInstance", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.InquiryPriceUpdateInstanceResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifyResourcePools(self, request):
        """刷新动态资源池

        :param request: Request instance for ModifyResourcePools.
        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourcePoolsRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyResourcePoolsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ModifyResourcePools", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifyResourcePoolsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifyResourceScheduleConfig(self, request):
        """修改yarn资源调度的资源配置

        :param request: Request instance for ModifyResourceScheduleConfig.
        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourceScheduleConfigRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyResourceScheduleConfigResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ModifyResourceScheduleConfig", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifyResourceScheduleConfigResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifyResourceScheduler(self, request):
        """修改了yarn的资源调度器，点击部署生效

        :param request: Request instance for ModifyResourceScheduler.
        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourceSchedulerRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyResourceSchedulerResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ModifyResourceScheduler", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifyResourceSchedulerResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def RunJobFlow(self, request):
        """创建流程作业

        :param request: Request instance for RunJobFlow.
        :type request: :class:`tencentcloud.emr.v20190103.models.RunJobFlowRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.RunJobFlowResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("RunJobFlow", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.RunJobFlowResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ScaleOutInstance(self, request):
        """实例扩容

        :param request: Request instance for ScaleOutInstance.
        :type request: :class:`tencentcloud.emr.v20190103.models.ScaleOutInstanceRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.ScaleOutInstanceResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ScaleOutInstance", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ScaleOutInstanceResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def SyncPodState(self, request):
        """EMR同步TKE中POD状态

        :param request: Request instance for SyncPodState.
        :type request: :class:`tencentcloud.emr.v20190103.models.SyncPodStateRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.SyncPodStateResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("SyncPodState", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.SyncPodStateResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def TerminateInstance(self, request):
        """销毁EMR实例。此接口仅支持弹性MapReduce正式计费版本。

        :param request: Request instance for TerminateInstance.
        :type request: :class:`tencentcloud.emr.v20190103.models.TerminateInstanceRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.TerminateInstanceResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("TerminateInstance", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.TerminateInstanceResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def TerminateTasks(self, request):
        """缩容Task节点

        :param request: Request instance for TerminateTasks.
        :type request: :class:`tencentcloud.emr.v20190103.models.TerminateTasksRequest`
        :rtype: :class:`tencentcloud.emr.v20190103.models.TerminateTasksResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("TerminateTasks", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.TerminateTasksResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 内部错误。
INTERNALERROR = 'InternalError'

# 查询异步任务错误。
INTERNALERROR_ASYNCREQUESTERROR = 'InternalError.AsyncRequestError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 当前子帐号无权执行该操作。
INVALIDPARAMETER_PERMISSIONDENIED = 'InvalidParameter.PermissionDenied'

# 非法的实例名。
INVALIDPARAMETERVALUE_ILLEGALINSTANCENAME = 'InvalidParameterValue.IllegalInstanceName'

# 非法的实例状态。
INVALIDPARAMETERVALUE_ILLEGALINSTANCESTATUS = 'InvalidParameterValue.IllegalInstanceStatus'

# 实例已删除。
INVALIDPARAMETERVALUE_INSTANCEHASBEENDELETED = 'InvalidParameterValue.InstanceHasBeenDeleted'

# 实例已隔离。
INVALIDPARAMETERVALUE_INSTANCEHASBEENISOLATED = 'InvalidParameterValue.InstanceHasBeenIsolated'

# limit取值范围[1,100]。
INVALIDPARAMETERVALUE_LIMITPARAOUTOFRANGE = 'InvalidParameterValue.LimitParaOutOfRange'

# 实例锁定失败。
INVALIDPARAMETERVALUE_LOCKFAILED = 'InvalidParameterValue.LockFailed'

# 实例版本不支持查询客户端信息。
INVALIDPARAMETERVALUE_MONGOVERSIONNOTSUPPORTQUERYCLIENT = 'InvalidParameterValue.MongoVersionNotSupportQueryClient'

# 未找到实例。
INVALIDPARAMETERVALUE_NOTFOUNDINSTANCE = 'InvalidParameterValue.NotFoundInstance'

# offset取值范围[0, 10000]。
INVALIDPARAMETERVALUE_OFFSETPARAOUTOFRANGE = 'InvalidParameterValue.OffsetParaOutOfRange'

# 密码不符合规范。
INVALIDPARAMETERVALUE_PASSWORDRULEFAILED = 'InvalidParameterValue.PasswordRuleFailed'

# 按量计费实例不允许续费。
INVALIDPARAMETERVALUE_POSTPAYRENEWERROR = 'InvalidParameterValue.PostPayRenewError'

# 项目不存在。
INVALIDPARAMETERVALUE_PROJECTNOTFOUND = 'InvalidParameterValue.ProjectNotFound'

# proxy版本不支持查询客户端信息，请联系工作人员进行升级。
INVALIDPARAMETERVALUE_PROXYNOTSUPPORTQUERYCLIENT = 'InvalidParameterValue.ProxyNotSupportQueryClient'

# 只能查询7天内的慢日志。
INVALIDPARAMETERVALUE_QUERYTIMEOUTOFRANGE = 'InvalidParameterValue.QueryTimeOutOfRange'

# 只能查询7天内的慢日志。
INVALIDPARAMETERVALUE_QUERYTIMERANGEBEYONDLIMIT = 'InvalidParameterValue.QueryTimeRangeBeyondLimit'

# 无效的地域。
INVALIDPARAMETERVALUE_REGIONERROR = 'InvalidParameterValue.RegionError'

# 地域尚不支持查询客户端信息。
INVALIDPARAMETERVALUE_REGIONNOTSUPPORTQUERYCLIENT = 'InvalidParameterValue.RegionNotSupportQueryClient'

# slowMS参数取值范围[100, 。
INVALIDPARAMETERVALUE_SLOWMSBELOWLIMIT = 'InvalidParameterValue.SlowMSBelowLimit'

# 起始时间晚于结束时间。
INVALIDPARAMETERVALUE_STARTTIMENOTBEFORETHANENDTIME = 'InvalidParameterValue.StartTimeNotBeforeThanEndTime'

# 实例处于不允许操作的状态。
INVALIDPARAMETERVALUE_STATUSABNORMAL = 'InvalidParameterValue.StatusAbnormal'

# 非法的时间格式。
INVALIDPARAMETERVALUE_TIMEFORMATERR = 'InvalidParameterValue.TimeFormatErr'

# 用户账户不存在。
INVALIDPARAMETERVALUE_USERNOTFOUND = 'InvalidParameterValue.UserNotFound'

# 未找到虚拟网络（子网）。
INVALIDPARAMETERVALUE_VPCIDORSUBNETIDNOTFOUND = 'InvalidParameterValue.VpcIdOrSubnetIdNotFound'

# 无效的可用区。
INVALIDPARAMETERVALUE_ZONEERROR = 'InvalidParameterValue.ZoneError'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 图片美颜失败，请更换图片。
FAILEDOPERATION_BEAUTIFYFAILED = 'FailedOperation.BeautifyFailed'

# 撤销任务无法被成功执行, 请重试。
FAILEDOPERATION_CANCELJOBFAILURE = 'FailedOperation.CancelJobFailure'

# 未检测到人脸。
FAILEDOPERATION_DETECTNOFACE = 'FailedOperation.DetectNoFace'

# 操作太频繁，触发频控。
FAILEDOPERATION_EFFECTFREQCTRL = 'FailedOperation.EffectFreqCtrl'

# 特效服务内部错误。
FAILEDOPERATION_EFFECTINNERERROR = 'FailedOperation.EffectInnerError'

# 人脸因太小被过滤，建议人脸分辨率不小于34*34。
FAILEDOPERATION_FACESIZETOOSMALL = 'FailedOperation.FaceSizeTooSmall'

# 操作太频繁，触发频控，请稍后重试。
FAILEDOPERATION_FREQCTRL = 'FailedOperation.FreqCtrl'

# 图片解码失败。
FAILEDOPERATION_IMAGEDECODEFAILED = 'FailedOperation.ImageDecodeFailed'

# 图片下载失败。
FAILEDOPERATION_IMAGEDOWNLOADERROR = 'FailedOperation.ImageDownloadError'

# 不支持灰色图。
FAILEDOPERATION_IMAGEGRAYNOTSUPPORT = 'FailedOperation.ImageGrayNotSupport'

# 不支持的图片文件。
FAILEDOPERATION_IMAGENOTSUPPORTED = 'FailedOperation.ImageNotSupported'

# 图片分辨率过大。
FAILEDOPERATION_IMAGERESOLUTIONEXCEED = 'FailedOperation.ImageResolutionExceed'

# 图片短边分辨率小于64。
FAILEDOPERATION_IMAGERESOLUTIONTOOSMALL = 'FailedOperation.ImageResolutionTooSmall'

# 图片数据太大。
FAILEDOPERATION_IMAGESIZEEXCEED = 'FailedOperation.ImageSizeExceed'

# 图片上传失败。
FAILEDOPERATION_IMAGEUPLOADFAILED = 'FailedOperation.ImageUploadFailed'

# 服务内部错误，请重试。
FAILEDOPERATION_INNERERROR = 'FailedOperation.InnerError'

# 内部错误。
FAILEDOPERATION_INTERNALERROR = 'FailedOperation.InternalError'

# 任务冲突。
FAILEDOPERATION_JOBCONFLICT = 'FailedOperation.JobConflict'

# 任务已撤销，请重新提交任务。
FAILEDOPERATION_JOBHASBEENCANCELED = 'FailedOperation.JobHasBeenCanceled'

# 任务已停止处理，请重新提交任务。
FAILEDOPERATION_JOBSTOPPROCESSING = 'FailedOperation.JobStopProcessing'

# 素材超过数量限制。
FAILEDOPERATION_MODELVALUEEXCEED = 'FailedOperation.ModelValueExceed'

# 参数错误。
FAILEDOPERATION_PARAMETERVALUEERROR = 'FailedOperation.ParameterValueError'

# 请求包体太大，建议在6M内（通常是参数中包括大的图片）。
FAILEDOPERATION_REQUESTENTITYTOOLARGE = 'FailedOperation.RequestEntityTooLarge'

# 后端服务超时，请重试。
FAILEDOPERATION_REQUESTTIMEOUT = 'FailedOperation.RequestTimeout'

# RPC请求失败，一般为算法微服务故障。
FAILEDOPERATION_RPCFAIL = 'FailedOperation.RpcFail'

# 系统内部错误。
FAILEDOPERATION_SERVERERROR = 'FailedOperation.ServerError'

# 未知错误。
FAILEDOPERATION_UNKNOWN = 'FailedOperation.Unknown'

# 内部错误。
INTERNALERROR = 'InternalError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 参数不合法。
INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'

# 图片中没有人脸。
INVALIDPARAMETER_NOFACEINPHOTO = 'InvalidParameter.NoFaceInPhoto'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# 大眼参数不合法。
INVALIDPARAMETERVALUE_EYEENLARGINGILLEGAL = 'InvalidParameterValue.EyeEnlargingIllegal'

# 瘦脸参数不合法。
INVALIDPARAMETERVALUE_FACELIFTINGILLEGAL = 'InvalidParameterValue.FaceLiftingIllegal'

# 人脸框参数不合法。
INVALIDPARAMETERVALUE_FACERECTINVALID = 'InvalidParameterValue.FaceRectInvalid'

# 第1个人脸框参数不合法。
INVALIDPARAMETERVALUE_FACERECTINVALIDFIRST = 'InvalidParameterValue.FaceRectInvalidFirst'

# 第2个人脸框参数不合法。
INVALIDPARAMETERVALUE_FACERECTINVALIDSECOND = 'InvalidParameterValue.FaceRectInvalidSecond'

# 第3个人脸框参数不合法。
INVALIDPARAMETERVALUE_FACERECTINVALIDTHRID = 'InvalidParameterValue.FaceRectInvalidThrid'

# 缺少参数，请检查图片参数是否为空。
INVALIDPARAMETERVALUE_IMAGEEMPTY = 'InvalidParameterValue.ImageEmpty'

# 图片不合法。
INVALIDPARAMETERVALUE_IMAGEINVALID = 'InvalidParameterValue.ImageInvalid'

# 图片数据太大。
INVALIDPARAMETERVALUE_IMAGESIZEEXCEED = 'InvalidParameterValue.ImageSizeExceed'

# 素材图片不合法, 必须是512*512的PNG图片。
INVALIDPARAMETERVALUE_LUTIMAGEINVALID = 'InvalidParameterValue.LutImageInvalid'

# 素材图片尺寸不合法，必须是512*512的PNG图片。
INVALIDPARAMETERVALUE_LUTIMAGESIZEINVALID = 'InvalidParameterValue.LutImageSizeInvalid'

# 素材不存在。
INVALIDPARAMETERVALUE_MODELIDNOTFOUND = 'InvalidParameterValue.ModelIdNotFound'

# 图片中没有人脸。
INVALIDPARAMETERVALUE_NOFACEINPHOTO = 'InvalidParameterValue.NoFaceInPhoto'

# 参数错误。
INVALIDPARAMETERVALUE_PARAMETERVALUEERROR = 'InvalidParameterValue.ParameterValueError'

# 磨皮参数不合法。
INVALIDPARAMETERVALUE_SMOOTHINGILLEGAL = 'InvalidParameterValue.SmoothingIllegal'

# URL格式不合法。
INVALIDPARAMETERVALUE_URLILLEGAL = 'InvalidParameterValue.UrlIllegal'

# 美白参数不合法。
INVALIDPARAMETERVALUE_WHITENINGILLEGAL = 'InvalidParameterValue.WhiteningIllegal'

# 资源正在发货中。
RESOURCEUNAVAILABLE_DELIVERING = 'ResourceUnavailable.Delivering'

# 帐号已被冻结。
RESOURCEUNAVAILABLE_FREEZE = 'ResourceUnavailable.Freeze'

# 获取认证信息失败。
RESOURCEUNAVAILABLE_GETAUTHINFOERROR = 'ResourceUnavailable.GetAuthInfoError'

# 帐号已欠费。
RESOURCEUNAVAILABLE_INARREARS = 'ResourceUnavailable.InArrears'

# 余额不足。
RESOURCEUNAVAILABLE_LOWBALANCE = 'ResourceUnavailable.LowBalance'

# 计费状态未知，请确认是否已在控制台开通服务。
RESOURCEUNAVAILABLE_NOTEXIST = 'ResourceUnavailable.NotExist'

# 服务未开通。
RESOURCEUNAVAILABLE_NOTREADY = 'ResourceUnavailable.NotReady'

# 资源已被回收。
RESOURCEUNAVAILABLE_RECOVER = 'ResourceUnavailable.Recover'

# 帐号已停服。
RESOURCEUNAVAILABLE_STOPUSING = 'ResourceUnavailable.StopUsing'

# 计费状态未知。
RESOURCEUNAVAILABLE_UNKNOWNSTATUS = 'ResourceUnavailable.UnknownStatus'

# 帐号已欠费。
RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.essbasic.v20210526 import models


class EssbasicClient(AbstractClient):
    _apiVersion = '2021-05-26'
    _endpoint = 'essbasic.tencentcloudapi.com'
    _service = 'essbasic'


    def ChannelBatchCancelFlows(self, request):
        """指定需要批量撤销的签署流程Id，批量撤销合同
        客户指定需要撤销的签署流程Id，最多100个，超过100不处理；接口失败后返回错误信息
        注意:
        能撤回合同的只能是合同的发起人或者发起企业的超管、法人

        :param request: Request instance for ChannelBatchCancelFlows.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelBatchCancelFlowsRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelBatchCancelFlowsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelBatchCancelFlows", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelBatchCancelFlowsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ChannelCancelMultiFlowSignQRCode(self, request):
        """此接口（ChannelCancelMultiFlowSignQRCode）用于取消一码多扫二维码。该接口对传入的二维码ID，若还在有效期内，可以提前失效。

        :param request: Request instance for ChannelCancelMultiFlowSignQRCode.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCancelMultiFlowSignQRCodeRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCancelMultiFlowSignQRCodeResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelCancelMultiFlowSignQRCode", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelCancelMultiFlowSignQRCodeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ChannelCreateBatchCancelFlowUrl(self, request):
        """指定需要批量撤销的签署流程Id，获取批量撤销链接
        客户指定需要撤销的签署流程Id，最多100个，超过100不处理；
        接口调用成功返回批量撤销合同的链接，通过链接跳转到电子签小程序完成批量撤销;
        注意:
        能撤回合同的只能是合同的发起人或者发起企业的超管、法人

        :param request: Request instance for ChannelCreateBatchCancelFlowUrl.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateBatchCancelFlowUrlRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateBatchCancelFlowUrlResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelCreateBatchCancelFlowUrl", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelCreateBatchCancelFlowUrlResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ChannelCreateConvertTaskApi(self, request):
        """渠道创建文件转换任务

        :param request: Request instance for ChannelCreateConvertTaskApi.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateConvertTaskApiRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateConvertTaskApiResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelCreateConvertTaskApi", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelCreateConvertTaskApiResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ChannelCreateFlowByFiles(self, request):
        """接口（ChannelCreateFlowByFiles）用于渠道版通过文件创建签署流程。此接口静默签能力不可直接使用，需要运营申请

        :param request: Request instance for ChannelCreateFlowByFiles.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowByFilesRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowByFilesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelCreateFlowByFiles", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelCreateFlowByFilesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ChannelCreateFlowGroupByFiles(self, request):
        """接口（ChannelCreateFlowGroupByFiles）用于通过多文件创建合同组签署流程。

        :param request: Request instance for ChannelCreateFlowGroupByFiles.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowGroupByFilesRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowGroupByFilesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelCreateFlowGroupByFiles", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelCreateFlowGroupByFilesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ChannelCreateFlowSignReview(self, request):
        """提交企业签署流程审批结果

        在通过接口(CreateFlowsByTemplates 或者ChannelCreateFlowByFiles)创建签署流程时，若指定了参数 NeedSignReview 为true,则可以调用此接口提交企业内部签署审批结果。
        若签署流程状态正常，且本企业存在签署方未签署，同一签署流程可以多次提交签署审批结果，签署时的最后一个“审批结果”有效。

        :param request: Request instance for ChannelCreateFlowSignReview.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowSignReviewRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowSignReviewResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelCreateFlowSignReview", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelCreateFlowSignReviewResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ChannelCreateMultiFlowSignQRCode(self, request):
        """此接口（ChannelCreateMultiFlowSignQRCode）用于创建一码多扫签署流程二维码。
        适用的模版仅限于B2C（1、无序签署，2、顺序签署时B静默签署，3、顺序签署时B非首位签署）、单C的模版，且模版中发起方没有填写控件。

        :param request: Request instance for ChannelCreateMultiFlowSignQRCode.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateMultiFlowSignQRCodeRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateMultiFlowSignQRCodeResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelCreateMultiFlowSignQRCode", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelCreateMultiFlowSignQRCodeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ChannelDescribeEmployees(self, request):
        """查询企业员工

        :param request: Request instance for ChannelDescribeEmployees.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelDescribeEmployeesRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelDescribeEmployeesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelDescribeEmployees", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelDescribeEmployeesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ChannelGetTaskResultApi(self, request):
        """渠道版查询转换任务状态

        :param request: Request instance for ChannelGetTaskResultApi.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelGetTaskResultApiRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelGetTaskResultApiResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelGetTaskResultApi", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelGetTaskResultApiResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ChannelVerifyPdf(self, request):
        """合同文件验签

        :param request: Request instance for ChannelVerifyPdf.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelVerifyPdfRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelVerifyPdfResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ChannelVerifyPdf", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ChannelVerifyPdfResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateConsoleLoginUrl(self, request):
        """此接口（CreateConsoleLoginUrl）用于创建渠道子客企业控制台Web端登录链接。Web端登录链接是子客控制台的唯一入口。
        若子客企业未激活，会进入企业激活流程,首次参与激活流程的经办人会成为超管。（若企业激活过程中填写信息有误，需要重置激活流程，可以换一个经办人OpenId获取新的链接进入。）
        若子客企业已激活，使用了新的经办人OpenId进入，则会进入经办人的实名流程。
        若子客企业、经办人均已完成认证，则会直接进入子客Web控制台。

        :param request: Request instance for CreateConsoleLoginUrl.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateConsoleLoginUrlRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.CreateConsoleLoginUrlResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateConsoleLoginUrl", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateConsoleLoginUrlResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateFlowsByTemplates(self, request):
        """接口（CreateFlowsByTemplates）用于使用多个模板批量创建签署流程。当前可批量发起合同（签署流程）数量最大为20个。

        :param request: Request instance for CreateFlowsByTemplates.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateFlowsByTemplatesRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.CreateFlowsByTemplatesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateFlowsByTemplates", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateFlowsByTemplatesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateSealByImage(self, request):
        """渠道通过图片为子客代创建印章，图片最大5m；此接口不可直接使用，需要运营申请

        :param request: Request instance for CreateSealByImage.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSealByImageRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.CreateSealByImageResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateSealByImage", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateSealByImageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateSignUrls(self, request):
        """创建跳转小程序查看或签署的链接；自动签署的签署方不创建签署链接；

        :param request: Request instance for CreateSignUrls.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSignUrlsRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.CreateSignUrlsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateSignUrls", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateSignUrlsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeFlowDetailInfo(self, request):
        """此接口（DescribeFlowDetailInfo）用于查询合同(签署流程)的详细信息。

        :param request: Request instance for DescribeFlowDetailInfo.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeFlowDetailInfoRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.DescribeFlowDetailInfoResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeFlowDetailInfo", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeFlowDetailInfoResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeResourceUrlsByFlows(self, request):
        """根据签署流程信息批量获取资源下载链接，需合作企业先进行授权

        :param request: Request instance for DescribeResourceUrlsByFlows.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeResourceUrlsByFlowsRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.DescribeResourceUrlsByFlowsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeResourceUrlsByFlows", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeResourceUrlsByFlowsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTemplates(self, request):
        """通过此接口（DescribeTemplates）查询该企业在电子签渠道版中配置的有效模板列表

        :param request: Request instance for DescribeTemplates.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeTemplatesRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.DescribeTemplatesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeTemplates", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTemplatesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeUsage(self, request):
        """此接口（DescribeUsage）用于获取渠道所有合作企业流量消耗情况。
         注: 此接口每日限频2次，若要扩大限制次数,请提前与客服经理或邮件至e-contract@tencent.com进行联系。

        :param request: Request instance for DescribeUsage.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeUsageRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.DescribeUsageResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeUsage", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeUsageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def GetDownloadFlowUrl(self, request):
        """此接口（GetDownloadFlowUrl）用于创建电子签批量下载地址，让合作企业进入控制台直接下载，支持客户合同（流程）按照自定义文件夹形式 分类下载。
        当前接口限制最多合同（流程）50个.

        :param request: Request instance for GetDownloadFlowUrl.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.GetDownloadFlowUrlRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.GetDownloadFlowUrlResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("GetDownloadFlowUrl", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.GetDownloadFlowUrlResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def OperateChannelTemplate(self, request):
        """此接口（OperateChannelTemplate）用于渠道侧将模板库中的模板对合作企业进行查询和设置, 其中包括可见性的修改以及对合作企业的设置.
        1、同步标识=select时：
        返回渠道侧模板库当前模板的属性.
        2、同步标识=update或者delete时：
        对渠道子客进行模板库中模板授权,修改操作

        :param request: Request instance for OperateChannelTemplate.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.OperateChannelTemplateRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.OperateChannelTemplateResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("OperateChannelTemplate", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.OperateChannelTemplateResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def PrepareFlows(self, request):
        """该接口 (PrepareFlows) 用于创建待发起文件
        用户通过该接口进入签署流程发起的确认页面，进行发起信息二次确认， 如果确认则进行正常发起。
        目前该接口只支持B2C，不建议使用。

        :param request: Request instance for PrepareFlows.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.PrepareFlowsRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.PrepareFlowsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("PrepareFlows", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.PrepareFlowsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def SyncProxyOrganization(self, request):
        """此接口（SyncProxyOrganization）用于同步渠道子客企业信息，主要是子客企业的营业执照，便于子客企业开通过程中不用手动上传。若有需要调用此接口，需要在创建控制链接CreateConsoleLoginUrl之后即刻进行调用。

        :param request: Request instance for SyncProxyOrganization.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.SyncProxyOrganizationRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.SyncProxyOrganizationResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("SyncProxyOrganization", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.SyncProxyOrganizationResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def SyncProxyOrganizationOperators(self, request):
        """此接口（SyncProxyOrganizationOperators）用于同步渠道子客企业经办人列表，主要是同步经办人的离职状态。子客Web控制台的组织架构管理，是依赖于渠道平台的，无法针对员工做新增/更新/离职等操作。
        若经办人信息有误，或者需要修改，也可以先将之前的经办人做离职操作，然后重新使用控制台链接CreateConsoleLoginUrl让经办人重新实名。

        :param request: Request instance for SyncProxyOrganizationOperators.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.SyncProxyOrganizationOperatorsRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.SyncProxyOrganizationOperatorsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("SyncProxyOrganizationOperators", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.SyncProxyOrganizationOperatorsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def UploadFiles(self, request):
        """此接口（UploadFiles）用于文件上传。
        调用时需要设置Domain 为 file.ess.tencent.cn

        :param request: Request instance for UploadFiles.
        :type request: :class:`tencentcloud.essbasic.v20210526.models.UploadFilesRequest`
        :rtype: :class:`tencentcloud.essbasic.v20210526.models.UploadFilesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UploadFiles", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.UploadFilesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class DBInstanceDetail(AbstractModel):
    """DB实例详情

    """

    def __init__(self):
        r"""
        :param InstanceId: DB实例Id
        :type InstanceId: str
        :param InstanceName: DB实例名称
        :type InstanceName: str
        :param Status: DB实例状态,-1:已隔离, 0:创建中, 1:流程中, 2:运行中, 3:未初始化
        :type Status: int
        :param StatusDesc: DB实例状态描述,-1:已隔离, 0:创建中, 1:流程中, 2:运行中, 3:未初始化
        :type StatusDesc: str
        :param DbVersion: DB实例版本
        :type DbVersion: str
        :param Vip: Vip信息
        :type Vip: str
        :param Vport: Vip使用的端口号
        :type Vport: int
        :param UniqueVpcId: 字符串型的私有网络ID
        :type UniqueVpcId: str
        :param UniqueSubnetId: 字符串型的私有网络子网ID
        :type UniqueSubnetId: str
        :param Shard: 是否为分布式版本,0:否,1:是
        :type Shard: int
        :param NodeNum: DB实例节点数
        :type NodeNum: int
        :param Cpu: CPU规格(单位:核数)
        :type Cpu: int
        :param Memory: 内存规格(单位:GB)
        :type Memory: int
        :param Disk: 磁盘规格(单位:GB)
        :type Disk: int
        :param ShardNum: 分布式类型的实例的分片数
        :type ShardNum: int
        :param Region: 地域
        :type Region: str
        :param Zone: 可用区
        :type Zone: str
        :param DbHosts: Db所在主机列表, 格式: m1,s1|m2,s2
        :type DbHosts: str
        :param HostRole: 主机角色, 1:主, 2:从, 3:主+从
        :type HostRole: int
        :param DbEngine: DB引擎，MySQL,Percona,MariaDB
        :type DbEngine: str
        :param CreateTime: 创建时间
        :type CreateTime: str
        """
        self.InstanceId = None
        self.InstanceName = None
        self.Status = None
        self.StatusDesc = None
        self.DbVersion = None
        self.Vip = None
        self.Vport = None
        self.UniqueVpcId = None
        self.UniqueSubnetId = None
        self.Shard = None
        self.NodeNum = None
        self.Cpu = None
        self.Memory = None
        self.Disk = None
        self.ShardNum = None
        self.Region = None
        self.Zone = None
        self.DbHosts = None
        self.HostRole = None
        self.DbEngine = None
        self.CreateTime = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.InstanceName = params.get("InstanceName")
        self.Status = params.get("Status")
        self.StatusDesc = params.get("StatusDesc")
        self.DbVersion = params.get("DbVersion")
        self.Vip = params.get("Vip")
        self.Vport = params.get("Vport")
        self.UniqueVpcId = params.get("UniqueVpcId")
        self.UniqueSubnetId = params.get("UniqueSubnetId")
        self.Shard = params.get("Shard")
        self.NodeNum = params.get("NodeNum")
        self.Cpu = params.get("Cpu")
        self.Memory = params.get("Memory")
        self.Disk = params.get("Disk")
        self.ShardNum = params.get("ShardNum")
        self.Region = params.get("Region")
        self.Zone = params.get("Zone")
        self.DbHosts = params.get("DbHosts")
        self.HostRole = params.get("HostRole")
        self.DbEngine = params.get("DbEngine")
        self.CreateTime = params.get("CreateTime")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeDBInstancesRequest(AbstractModel):
    """DescribeDBInstances请求参数结构体

    """

    def __init__(self):
        r"""
        :param InstanceId: 独享集群实例Id
        :type InstanceId: str
        :param HostId: 独享集群主机Id
        :type HostId: str
        :param Limit: 分页返回数量
        :type Limit: int
        :param Offset: 分页偏移量
        :type Offset: int
        :param ShardType: 实例类型,0:mariadb, 1:tdsql
        :type ShardType: list of int
        """
        self.InstanceId = None
        self.HostId = None
        self.Limit = None
        self.Offset = None
        self.ShardType = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.HostId = params.get("HostId")
        self.Limit = params.get("Limit")
        self.Offset = params.get("Offset")
        self.ShardType = params.get("ShardType")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeDBInstancesResponse(AbstractModel):
    """DescribeDBInstances返回参数结构体

    """

    def __init__(self):
        r"""
        :param Instances: 独享集群内的DB实例列表
        :type Instances: list of DBInstanceDetail
        :param TotalCount: 独享集群内的DB实例总数
        :type TotalCount: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Instances = None
        self.TotalCount = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Instances") is not None:
            self.Instances = []
            for item in params.get("Instances"):
                obj = DBInstanceDetail()
                obj._deserialize(item)
                self.Instances.append(obj)
        self.TotalCount = params.get("TotalCount")
        self.RequestId = params.get("RequestId")


class DescribeHostListRequest(AbstractModel):
    """DescribeHostList请求参数结构体

    """

    def __init__(self):
        r"""
        :param InstanceId: 独享集群实例Id
        :type InstanceId: str
        :param Limit: 分页返回数量
        :type Limit: int
        :param Offset: 分页偏移量
        :type Offset: int
        :param AssignStatus: 分配状态过滤，0-可分配，1-禁止分配
        :type AssignStatus: list of int
        """
        self.InstanceId = None
        self.Limit = None
        self.Offset = None
        self.AssignStatus = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.Limit = params.get("Limit")
        self.Offset = params.get("Offset")
        self.AssignStatus = params.get("AssignStatus")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeHostListResponse(AbstractModel):
    """DescribeHostList返回参数结构体

    """

    def __init__(self):
        r"""
        :param TotalCount: 主机总数
        :type TotalCount: int
        :param Hosts: 主机详情
        :type Hosts: list of HostDetail
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.TotalCount = None
        self.Hosts = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("Hosts") is not None:
            self.Hosts = []
            for item in params.get("Hosts"):
                obj = HostDetail()
                obj._deserialize(item)
                self.Hosts.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeInstanceDetail(AbstractModel):
    """独享集群详情

    """

    def __init__(self):
        r"""
        :param InstanceId: 独享集群实例Id
        :type InstanceId: str
        :param InstanceName: 独享集群实例名称
        :type InstanceName: str
        :param Region: 地域
        :type Region: str
        :param ProductId: 产品ID, 0:CDB, 1:TDSQL
        :type ProductId: int
        :param Type: 集群类型, 0:公有云, 1:金融围笼, 2:CDC集群
        :type Type: int
        :param HostType: 主机类型, 0:物理机, 1:CVM机型, 2:CDC机型
        :type HostType: int
        :param AutoRenewFlag: 自动续费标志, 0:未设置, 1:自动续费, 2:到期不续费
        :type AutoRenewFlag: int
        :param Status: 集群状态
        :type Status: int
        :param StatusDesc: 集群状态描述
        :type StatusDesc: str
        :param CreateTime: 创建时间
        :type CreateTime: str
        :param PeriodEndTime: 到期时间
        :type PeriodEndTime: str
        :param HostNum: 主机数
        :type HostNum: int
        :param DbNum: DB实例数
        :type DbNum: int
        :param AssignStrategy: 分配策略, 0:紧凑, 1:均匀
        :type AssignStrategy: int
        :param CpuSpec: 总主机CPU(单位:核数)
        :type CpuSpec: int
        :param CpuAssigned: 总已分配CPU(单位:核数)
        :type CpuAssigned: int
        :param CpuAssignable: 总可分配CPU(单位:核数)
        :type CpuAssignable: int
        :param MemorySpec: 总主机内存(单位:GB)
        :type MemorySpec: int
        :param MemoryAssigned: 总已分配内存(单位:GB)
        :type MemoryAssigned: int
        :param MemoryAssignable: 总可分配内存(单位:GB)
        :type MemoryAssignable: int
        :param DiskSpec: 总机器磁盘(单位:GB)
        :type DiskSpec: int
        :param DiskAssigned: 总已分配磁盘(单位:GB)
        :type DiskAssigned: int
        :param DiskAssignable: 总可分配磁盘(单位:GB)
        :type DiskAssignable: int
        :param Zone: 可用区
        :type Zone: str
        :param FenceId: 金融围笼ID
注意：此字段可能返回 null，表示取不到有效值。
        :type FenceId: str
        :param ClusterId: 所属集群ID(默认集群为空)
注意：此字段可能返回 null，表示取不到有效值。
        :type ClusterId: str
        """
        self.InstanceId = None
        self.InstanceName = None
        self.Region = None
        self.ProductId = None
        self.Type = None
        self.HostType = None
        self.AutoRenewFlag = None
        self.Status = None
        self.StatusDesc = None
        self.CreateTime = None
        self.PeriodEndTime = None
        self.HostNum = None
        self.DbNum = None
        self.AssignStrategy = None
        self.CpuSpec = None
        self.CpuAssigned = None
        self.CpuAssignable = None
        self.MemorySpec = None
        self.MemoryAssigned = None
        self.MemoryAssignable = None
        self.DiskSpec = None
        self.DiskAssigned = None
        self.DiskAssignable = None
        self.Zone = None
        self.FenceId = None
        self.ClusterId = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.InstanceName = params.get("InstanceName")
        self.Region = params.get("Region")
        self.ProductId = params.get("ProductId")
        self.Type = params.get("Type")
        self.HostType = params.get("HostType")
        self.AutoRenewFlag = params.get("AutoRenewFlag")
        self.Status = params.get("Status")
        self.StatusDesc = params.get("StatusDesc")
        self.CreateTime = params.get("CreateTime")
        self.PeriodEndTime = params.get("PeriodEndTime")
        self.HostNum = params.get("HostNum")
        self.DbNum = params.get("DbNum")
        self.AssignStrategy = params.get("AssignStrategy")
        self.CpuSpec = params.get("CpuSpec")
        self.CpuAssigned = params.get("CpuAssigned")
        self.CpuAssignable = params.get("CpuAssignable")
        self.MemorySpec = params.get("MemorySpec")
        self.MemoryAssigned = params.get("MemoryAssigned")
        self.MemoryAssignable = params.get("MemoryAssignable")
        self.DiskSpec = params.get("DiskSpec")
        self.DiskAssigned = params.get("DiskAssigned")
        self.DiskAssignable = params.get("DiskAssignable")
        self.Zone = params.get("Zone")
        self.FenceId = params.get("FenceId")
        self.ClusterId = params.get("ClusterId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeInstanceDetailRequest(AbstractModel):
    """DescribeInstanceDetail请求参数结构体

    """

    def __init__(self):
        r"""
        :param InstanceId: 独享集群实例Id
        :type InstanceId: str
        """
        self.InstanceId = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeInstanceDetailResponse(AbstractModel):
    """DescribeInstanceDetail返回参数结构体

    """

    def __init__(self):
        r"""
        :param InstanceId: 独享集群实例Id
        :type InstanceId: str
        :param InstanceName: 独享集群实例名称
        :type InstanceName: str
        :param Region: 地域
        :type Region: str
        :param ProductId: 产品ID, 0:CDB, 1:TDSQL
        :type ProductId: int
        :param Type: 集群类型, 0:公有云, 1:金融围笼
        :type Type: int
        :param HostType: 主机类型, 0:物理机, 1:cvm本地盘, 2:cvm云盘
        :type HostType: int
        :param AutoRenewFlag: 自动续费标志, 0:未设置, 1:自动续费, 2:到期不续费
        :type AutoRenewFlag: int
        :param Status: 集群状态
        :type Status: int
        :param StatusDesc: 集群状态描述
        :type StatusDesc: str
        :param CreateTime: 创建时间
        :type CreateTime: str
        :param PeriodEndTime: 到期时间
        :type PeriodEndTime: str
        :param HostNum: 主机数
        :type HostNum: int
        :param DbNum: Db实例数
        :type DbNum: int
        :param AssignStrategy: 分配策略, 0:紧凑, 1:均匀
        :type AssignStrategy: int
        :param CpuSpec: 总主机CPU(单位:核)
        :type CpuSpec: int
        :param CpuAssigned: 总已分配CPU(单位:核)
        :type CpuAssigned: int
        :param CpuAssignable: 总可分配CPU(单位:核)
        :type CpuAssignable: int
        :param MemorySpec: 总主机内存(单位:GB)
        :type MemorySpec: int
        :param MemoryAssigned: 总已分配内存(单位:GB)
        :type MemoryAssigned: int
        :param MemoryAssignable: 总可分配内存(单位:GB)
        :type MemoryAssignable: int
        :param DiskSpec: 总机器磁盘(单位:GB)
        :type DiskSpec: int
        :param DiskAssigned: 总已分配磁盘(单位:GB)
        :type DiskAssigned: int
        :param DiskAssignable: 总可分配磁盘(单位:GB)
        :type DiskAssignable: int
        :param Zone: 可用区
        :type Zone: str
        :param FenceId: 金融围笼ID
注意：此字段可能返回 null，表示取不到有效值。
        :type FenceId: str
        :param ClusterId: 所属集群ID(默认集群为空)
注意：此字段可能返回 null，表示取不到有效值。
        :type ClusterId: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.InstanceId = None
        self.InstanceName = None
        self.Region = None
        self.ProductId = None
        self.Type = None
        self.HostType = None
        self.AutoRenewFlag = None
        self.Status = None
        self.StatusDesc = None
        self.CreateTime = None
        self.PeriodEndTime = None
        self.HostNum = None
        self.DbNum = None
        self.AssignStrategy = None
        self.CpuSpec = None
        self.CpuAssigned = None
        self.CpuAssignable = None
        self.MemorySpec = None
        self.MemoryAssigned = None
        self.MemoryAssignable = None
        self.DiskSpec = None
        self.DiskAssigned = None
        self.DiskAssignable = None
        self.Zone = None
        self.FenceId = None
        self.ClusterId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.InstanceName = params.get("InstanceName")
        self.Region = params.get("Region")
        self.ProductId = params.get("ProductId")
        self.Type = params.get("Type")
        self.HostType = params.get("HostType")
        self.AutoRenewFlag = params.get("AutoRenewFlag")
        self.Status = params.get("Status")
        self.StatusDesc = params.get("StatusDesc")
        self.CreateTime = params.get("CreateTime")
        self.PeriodEndTime = params.get("PeriodEndTime")
        self.HostNum = params.get("HostNum")
        self.DbNum = params.get("DbNum")
        self.AssignStrategy = params.get("AssignStrategy")
        self.CpuSpec = params.get("CpuSpec")
        self.CpuAssigned = params.get("CpuAssigned")
        self.CpuAssignable = params.get("CpuAssignable")
        self.MemorySpec = params.get("MemorySpec")
        self.MemoryAssigned = params.get("MemoryAssigned")
        self.MemoryAssignable = params.get("MemoryAssignable")
        self.DiskSpec = params.get("DiskSpec")
        self.DiskAssigned = params.get("DiskAssigned")
        self.DiskAssignable = params.get("DiskAssignable")
        self.Zone = params.get("Zone")
        self.FenceId = params.get("FenceId")
        self.ClusterId = params.get("ClusterId")
        self.RequestId = params.get("RequestId")


class DescribeInstanceListRequest(AbstractModel):
    """DescribeInstanceList请求参数结构体

    """

    def __init__(self):
        r"""
        :param Limit: 分页返回数量
        :type Limit: int
        :param Offset: 分页偏移量
        :type Offset: int
        :param OrderBy: 排序字段，createTime,instancename两者之一
        :type OrderBy: str
        :param SortBy: 排序规则，desc,asc两者之一
        :type SortBy: str
        :param ProductId: 按产品过滤，0:CDB, 1:TDSQL
        :type ProductId: list of int
        :param InstanceId: 按实例ID过滤
        :type InstanceId: list of str
        :param InstanceName: 按实例名称过滤
        :type InstanceName: list of str
        :param FenceId: 按金融围笼ID过滤
        :type FenceId: list of str
        :param Status: 按实例状态过滤, -1:已隔离, 0:创建中, 1:运行中, 2:扩容中, 3:删除中
        :type Status: list of int
        :param ClusterId: 按所属集群ID过滤
        :type ClusterId: list of str
        """
        self.Limit = None
        self.Offset = None
        self.OrderBy = None
        self.SortBy = None
        self.ProductId = None
        self.InstanceId = None
        self.InstanceName = None
        self.FenceId = None
        self.Status = None
        self.ClusterId = None


    def _deserialize(self, params):
        self.Limit = params.get("Limit")
        self.Offset = params.get("Offset")
        self.OrderBy = params.get("OrderBy")
        self.SortBy = params.get("SortBy")
        self.ProductId = params.get("ProductId")
        self.InstanceId = params.get("InstanceId")
        self.InstanceName = params.get("InstanceName")
        self.FenceId = params.get("FenceId")
        self.Status = params.get("Status")
        self.ClusterId = params.get("ClusterId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeInstanceListResponse(AbstractModel):
    """DescribeInstanceList返回参数结构体

    """

    def __init__(self):
        r"""
        :param Instances: 独享集群列表
        :type Instances: list of DescribeInstanceDetail
        :param TotalCount: 独享集群实例总数
        :type TotalCount: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Instances = None
        self.TotalCount = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Instances") is not None:
            self.Instances = []
            for item in params.get("Instances"):
                obj = DescribeInstanceDetail()
                obj._deserialize(item)
                self.Instances.append(obj)
        self.TotalCount = params.get("TotalCount")
        self.RequestId = params.get("RequestId")


class DescribeInstancesRequest(AbstractModel):
    """DescribeInstances请求参数结构体

    """

    def __init__(self):
        r"""
        :param InstanceTypes: 集群类型: 0 一主一备, 1 一主两备...N-1 一主N备
        :type InstanceTypes: list of int
        :param ProductIds: 产品ID:  0 MYSQL，1 TDSQL
        :type ProductIds: list of int
        :param InstanceIds: 集群uuid: 如 dbdc-q810131s
        :type InstanceIds: list of str
        :param FenceFlag: 是否按金融围笼标志搜索
        :type FenceFlag: bool
        :param InstanceName: 按实例名字模糊匹配
        :type InstanceName: str
        :param PageSize: 每页数目, 整型
        :type PageSize: int
        :param PageNumber: 页码, 整型
        :type PageNumber: int
        :param OrderBy: 排序字段，枚举：createtime,groupname
        :type OrderBy: str
        :param OrderByType: 排序方式: asc升序, desc降序
        :type OrderByType: str
        :param InstanceStatus: 集群状态: -2 已删除, -1 已隔离, 0 创建中, 1 运行中, 2 扩容中, 3 删除中
        :type InstanceStatus: int
        """
        self.InstanceTypes = None
        self.ProductIds = None
        self.InstanceIds = None
        self.FenceFlag = None
        self.InstanceName = None
        self.PageSize = None
        self.PageNumber = None
        self.OrderBy = None
        self.OrderByType = None
        self.InstanceStatus = None


    def _deserialize(self, params):
        self.InstanceTypes = params.get("InstanceTypes")
        self.ProductIds = params.get("ProductIds")
        self.InstanceIds = params.get("InstanceIds")
        self.FenceFlag = params.get("FenceFlag")
        self.InstanceName = params.get("InstanceName")
        self.PageSize = params.get("PageSize")
        self.PageNumber = params.get("PageNumber")
        self.OrderBy = params.get("OrderBy")
        self.OrderByType = params.get("OrderByType")
        self.InstanceStatus = params.get("InstanceStatus")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeInstancesResponse(AbstractModel):
    """DescribeInstances返回参数结构体

    """

    def __init__(self):
        r"""
        :param TotalCount: 集群数量
        :type TotalCount: int
        :param Instances: 集群扩展信息
        :type Instances: list of InstanceExpand
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.TotalCount = None
        self.Instances = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("Instances") is not None:
            self.Instances = []
            for item in params.get("Instances"):
                obj = InstanceExpand()
                obj._deserialize(item)
                self.Instances.append(obj)
        self.RequestId = params.get("RequestId")


class DeviceInfo(AbstractModel):
    """设备信息

    """

    def __init__(self):
        r"""
        :param DeviceId: 设备ID
        :type DeviceId: int
        :param DeviceNo: 设备No
        :type DeviceNo: str
        :param DevClass: 设备类型
        :type DevClass: str
        :param MaxMemory: 设备总内存，单位GB
        :type MaxMemory: float
        :param MaxDisk: 设备总磁盘，单位GB
        :type MaxDisk: float
        :param RestMemory: 设备剩余内存，单位GB
        :type RestMemory: float
        :param RestDisk: 设备剩余磁盘，单位GB
        :type RestDisk: float
        :param RawDeviceNum: 设备机器个数
        :type RawDeviceNum: int
        :param InstanceNum: 数据库实例个数
        :type InstanceNum: int
        """
        self.DeviceId = None
        self.DeviceNo = None
        self.DevClass = None
        self.MaxMemory = None
        self.MaxDisk = None
        self.RestMemory = None
        self.RestDisk = None
        self.RawDeviceNum = None
        self.InstanceNum = None


    def _deserialize(self, params):
        self.DeviceId = params.get("DeviceId")
        self.DeviceNo = params.get("DeviceNo")
        self.DevClass = params.get("DevClass")
        self.MaxMemory = params.get("MaxMemory")
        self.MaxDisk = params.get("MaxDisk")
        self.RestMemory = params.get("RestMemory")
        self.RestDisk = params.get("RestDisk")
        self.RawDeviceNum = params.get("RawDeviceNum")
        self.InstanceNum = params.get("InstanceNum")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class HostDetail(AbstractModel):
    """主机详情

    """

    def __init__(self):
        r"""
        :param HostId: 主机Id
        :type HostId: str
        :param HostName: 主机名称
        :type HostName: str
        :param Zone: 可用区
        :type Zone: str
        :param Status: 主机状态
        :type Status: int
        :param AssignStatus: 分配DB实例状态,0:可分配,1:不可分配
        :type AssignStatus: int
        :param HostType: 主机类型, 0:物理机, 1:cvm本地盘, 2:cvm云盘
        :type HostType: int
        :param DbNum: DB实例数
        :type DbNum: int
        :param CpuSpec: 主机CPU(单位:核数)
        :type CpuSpec: int
        :param CpuAssigned: 已分配CPU(单位:核数)
        :type CpuAssigned: int
        :param CpuAssignable: 可分配CPU(单位:核数)
        :type CpuAssignable: int
        :param MemorySpec: 主机内存(单位:GB)
        :type MemorySpec: int
        :param MemoryAssigned: 已分配内存(单位:GB)
        :type MemoryAssigned: int
        :param MemoryAssignable: 可分配内存(单位:GB)
        :type MemoryAssignable: int
        :param DiskSpec: 主机磁盘(单位:GB)
        :type DiskSpec: int
        :param DiskAssigned: 已分配磁盘(单位:GB)
        :type DiskAssigned: int
        :param DiskAssignable: 可分配磁盘(GB)
        :type DiskAssignable: int
        :param CpuRatio: CPU分配比
        :type CpuRatio: float
        :param MemoryRatio: 内存分配比
        :type MemoryRatio: float
        :param DiskRatio: 磁盘分配比
        :type DiskRatio: float
        :param MachineName: 机型名称
        :type MachineName: str
        :param MachineType: 机型类别
        :type MachineType: str
        :param PidTag: 计费标签
        :type PidTag: str
        :param Pid: 计费ID
        :type Pid: int
        """
        self.HostId = None
        self.HostName = None
        self.Zone = None
        self.Status = None
        self.AssignStatus = None
        self.HostType = None
        self.DbNum = None
        self.CpuSpec = None
        self.CpuAssigned = None
        self.CpuAssignable = None
        self.MemorySpec = None
        self.MemoryAssigned = None
        self.MemoryAssignable = None
        self.DiskSpec = None
        self.DiskAssigned = None
        self.DiskAssignable = None
        self.CpuRatio = None
        self.MemoryRatio = None
        self.DiskRatio = None
        self.MachineName = None
        self.MachineType = None
        self.PidTag = None
        self.Pid = None


    def _deserialize(self, params):
        self.HostId = params.get("HostId")
        self.HostName = params.get("HostName")
        self.Zone = params.get("Zone")
        self.Status = params.get("Status")
        self.AssignStatus = params.get("AssignStatus")
        self.HostType = params.get("HostType")
        self.DbNum = params.get("DbNum")
        self.CpuSpec = params.get("CpuSpec")
        self.CpuAssigned = params.get("CpuAssigned")
        self.CpuAssignable = params.get("CpuAssignable")
        self.MemorySpec = params.get("MemorySpec")
        self.MemoryAssigned = params.get("MemoryAssigned")
        self.MemoryAssignable = params.get("MemoryAssignable")
        self.DiskSpec = params.get("DiskSpec")
        self.DiskAssigned = params.get("DiskAssigned")
        self.DiskAssignable = params.get("DiskAssignable")
        self.CpuRatio = params.get("CpuRatio")
        self.MemoryRatio = params.get("MemoryRatio")
        self.DiskRatio = params.get("DiskRatio")
        self.MachineName = params.get("MachineName")
        self.MachineType = params.get("MachineType")
        self.PidTag = params.get("PidTag")
        self.Pid = params.get("Pid")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class InstanceDetail(AbstractModel):
    """集群容量信息。

    """

    def __init__(self):
        r"""
        :param Status: 集群状态，0：运行中，1：不在运行
        :type Status: int
        :param ReadWriteTotalLeaveMemory: 读写集群剩余内存容量，单位GB
        :type ReadWriteTotalLeaveMemory: float
        :param ReadWriteTotalLeaveDisk: 读写集群剩余磁盘容量，单位GB
        :type ReadWriteTotalLeaveDisk: float
        :param ReadWriteTotalMemory: 读写集群总内存容量，单位GB
        :type ReadWriteTotalMemory: float
        :param ReadWriteTotalDisk: 读写集群总磁盘容量，单位GB
        :type ReadWriteTotalDisk: float
        :param ReadOnlyTotalLeaveMemory: 只读集群剩余内存容量，单位GB
        :type ReadOnlyTotalLeaveMemory: float
        :param ReadOnlyTotalLeaveDisk: 只读集群剩余磁盘容量，单位GB
        :type ReadOnlyTotalLeaveDisk: float
        :param ReadOnlyTotalMemory: 只读集群总内存容量，单位GB
        :type ReadOnlyTotalMemory: float
        :param ReadOnlyTotalDisk: 只读集群总磁盘容量，单位GB
        :type ReadOnlyTotalDisk: float
        :param InstanceDeviceInfos: 集群设备详情
        :type InstanceDeviceInfos: list of InstanceDeviceInfo
        """
        self.Status = None
        self.ReadWriteTotalLeaveMemory = None
        self.ReadWriteTotalLeaveDisk = None
        self.ReadWriteTotalMemory = None
        self.ReadWriteTotalDisk = None
        self.ReadOnlyTotalLeaveMemory = None
        self.ReadOnlyTotalLeaveDisk = None
        self.ReadOnlyTotalMemory = None
        self.ReadOnlyTotalDisk = None
        self.InstanceDeviceInfos = None


    def _deserialize(self, params):
        self.Status = params.get("Status")
        self.ReadWriteTotalLeaveMemory = params.get("ReadWriteTotalLeaveMemory")
        self.ReadWriteTotalLeaveDisk = params.get("ReadWriteTotalLeaveDisk")
        self.ReadWriteTotalMemory = params.get("ReadWriteTotalMemory")
        self.ReadWriteTotalDisk = params.get("ReadWriteTotalDisk")
        self.ReadOnlyTotalLeaveMemory = params.get("ReadOnlyTotalLeaveMemory")
        self.ReadOnlyTotalLeaveDisk = params.get("ReadOnlyTotalLeaveDisk")
        self.ReadOnlyTotalMemory = params.get("ReadOnlyTotalMemory")
        self.ReadOnlyTotalDisk = params.get("ReadOnlyTotalDisk")
        if params.get("InstanceDeviceInfos") is not None:
            self.InstanceDeviceInfos = []
            for item in params.get("InstanceDeviceInfos"):
                obj = InstanceDeviceInfo()
                obj._deserialize(item)
                self.InstanceDeviceInfos.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class InstanceDeviceInfo(AbstractModel):
    """集群设备组信息。

    """

    def __init__(self):
        r"""
        :param InstanceId: 集群ID
注意：此字段可能返回 null，表示取不到有效值。
        :type InstanceId: str
        :param ReadWriteDevice: 读写设备组
注意：此字段可能返回 null，表示取不到有效值。
        :type ReadWriteDevice: list of DeviceInfo
        :param ReadOnlyDevice: 只读设备组
注意：此字段可能返回 null，表示取不到有效值。
        :type ReadOnlyDevice: list of DeviceInfo
        :param FreeDevice: 空闲设备组
注意：此字段可能返回 null，表示取不到有效值。
        :type FreeDevice: list of DeviceInfo
        """
        self.InstanceId = None
        self.ReadWriteDevice = None
        self.ReadOnlyDevice = None
        self.FreeDevice = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        if params.get("ReadWriteDevice") is not None:
            self.ReadWriteDevice = []
            for item in params.get("ReadWriteDevice"):
                obj = DeviceInfo()
                obj._deserialize(item)
                self.ReadWriteDevice.append(obj)
        if params.get("ReadOnlyDevice") is not None:
            self.ReadOnlyDevice = []
            for item in params.get("ReadOnlyDevice"):
                obj = DeviceInfo()
                obj._deserialize(item)
                self.ReadOnlyDevice.append(obj)
        if params.get("FreeDevice") is not None:
            self.FreeDevice = []
            for item in params.get("FreeDevice"):
                obj = DeviceInfo()
                obj._deserialize(item)
                self.FreeDevice.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class InstanceExpand(AbstractModel):
    """集群扩展信息。

    """

    def __init__(self):
        r"""
        :param InstanceId: 集群ID
        :type InstanceId: str
        :param InstanceName: 集群名称
        :type InstanceName: str
        :param AppId: 用户ID
        :type AppId: int
        :param Region: 地域
        :type Region: str
        :param Zone: 可用区
        :type Zone: str
        :param InstanceType: 集群类型： 0：一主一备，1：一主两备
        :type InstanceType: int
        :param InstanceStatus: 集群状态: 0 集群创建中, 1 集群有效, 2 集群扩容中, 3 集群删除中, 4 集群缩容中 -1 集群已隔离 -2 集群已删除
        :type InstanceStatus: int
        :param CreateTime: 创建时间
        :type CreateTime: str
        :param AutoRenewFlag: 实例自动续费标识： 0正常续费 1自动续费 2到期不续费
        :type AutoRenewFlag: int
        :param Machine: 机型
        :type Machine: str
        :param PeriodEndTime: 过期时间
        :type PeriodEndTime: str
        :param InstanceDetail: 集群信息
        :type InstanceDetail: :class:`tencentcloud.dbdc.v20201029.models.InstanceDetail`
        :param Pid: 计费侧的产品ID
        :type Pid: int
        """
        self.InstanceId = None
        self.InstanceName = None
        self.AppId = None
        self.Region = None
        self.Zone = None
        self.InstanceType = None
        self.InstanceStatus = None
        self.CreateTime = None
        self.AutoRenewFlag = None
        self.Machine = None
        self.PeriodEndTime = None
        self.InstanceDetail = None
        self.Pid = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.InstanceName = params.get("InstanceName")
        self.AppId = params.get("AppId")
        self.Region = params.get("Region")
        self.Zone = params.get("Zone")
        self.InstanceType = params.get("InstanceType")
        self.InstanceStatus = params.get("InstanceStatus")
        self.CreateTime = params.get("CreateTime")
        self.AutoRenewFlag = params.get("AutoRenewFlag")
        self.Machine = params.get("Machine")
        self.PeriodEndTime = params.get("PeriodEndTime")
        if params.get("InstanceDetail") is not None:
            self.InstanceDetail = InstanceDetail()
            self.InstanceDetail._deserialize(params.get("InstanceDetail"))
        self.Pid = params.get("Pid")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyInstanceNameRequest(AbstractModel):
    """ModifyInstanceName请求参数结构体

    """

    def __init__(self):
        r"""
        :param InstanceId: 独享集群实例Id
        :type InstanceId: str
        :param InstanceName: 独享集群实例名称
        :type InstanceName: str
        """
        self.InstanceId = None
        self.InstanceName = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.InstanceName = params.get("InstanceName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyInstanceNameResponse(AbstractModel):
    """ModifyInstanceName返回参数结构体

    """

    def __init__(self):
        r"""
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.tics.v20181115 import models


class TicsClient(AbstractClient):
    _apiVersion = '2018-11-15'
    _endpoint = 'tics.tencentcloudapi.com'
    _service = 'tics'


    def DescribeDomainInfo(self, request):
        """提供域名相关的基础信息以及与攻击事件（团伙、家族）、恶意文件等相关联信息。

        :param request: Request instance for DescribeDomainInfo.
        :type request: :class:`tencentcloud.tics.v20181115.models.DescribeDomainInfoRequest`
        :rtype: :class:`tencentcloud.tics.v20181115.models.DescribeDomainInfoResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeDomainInfo", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeDomainInfoResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeFileInfo(self, request):
        """提供文件相关的基础信息以及与攻击事件（团伙、家族）、恶意文件等相关联信息。

        :param request: Request instance for DescribeFileInfo.
        :type request: :class:`tencentcloud.tics.v20181115.models.DescribeFileInfoRequest`
        :rtype: :class:`tencentcloud.tics.v20181115.models.DescribeFileInfoResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeFileInfo", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeFileInfoResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeIpInfo(self, request):
        """提供IP相关的基础信息以及与攻击事件（团伙、家族）、恶意文件等相关联信息。

        :param request: Request instance for DescribeIpInfo.
        :type request: :class:`tencentcloud.tics.v20181115.models.DescribeIpInfoRequest`
        :rtype: :class:`tencentcloud.tics.v20181115.models.DescribeIpInfoResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeIpInfo", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeIpInfoResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeThreatInfo(self, request):
        """提供IP和域名相关威胁情报信息查询，这些信息可以辅助检测失陷主机、帮助SIEM/SOC等系统做研判决策、帮助运营团队对设备报警的编排处理。

        :param request: Request instance for DescribeThreatInfo.
        :type request: :class:`tencentcloud.tics.v20181115.models.DescribeThreatInfoRequest`
        :rtype: :class:`tencentcloud.tics.v20181115.models.DescribeThreatInfoResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeThreatInfo", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeThreatInfoResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 音频解码失败。
FAILEDOPERATION_AUDIODECODEFAILED = 'FailedOperation.AudioDecodeFailed'

# 音频编码失败。
FAILEDOPERATION_AUDIOENCODEFAILED = 'FailedOperation.AudioEncodeFailed'

# 人体特征检测失败。
FAILEDOPERATION_BODYFEATUREFAIL = 'FailedOperation.BodyFeatureFail'

# 人体关键点检测失败。
FAILEDOPERATION_BODYJOINTSFAIL = 'FailedOperation.BodyJointsFail'

# 人体质量分过低。
FAILEDOPERATION_BODYQUALITYNOTQUALIFIED = 'FailedOperation.BodyQualityNotQualified'

# 输入的人体框不合法。
FAILEDOPERATION_BODYRECTILLEGAL = 'FailedOperation.BodyRectIllegal'

# 输入的人体框数量不合法。
FAILEDOPERATION_BODYRECTNUMILLEGAL = 'FailedOperation.BodyRectNumIllegal'

# 创建动作轨迹失败，请选择符合要求的人体图片。
FAILEDOPERATION_CREATETRACEFAILED = 'FailedOperation.CreateTraceFailed'

# 文件下载失败。
FAILEDOPERATION_DOWNLOADERROR = 'FailedOperation.DownloadError'

# 搜索的人体库为空。
FAILEDOPERATION_GROUPEMPTY = 'FailedOperation.GroupEmpty'

# 人体检测失败。
FAILEDOPERATION_IMAGEBODYDETECTFAILED = 'FailedOperation.ImageBodyDetectFailed'

# 图片解码失败。
FAILEDOPERATION_IMAGEDECODEFAILED = 'FailedOperation.ImageDecodeFailed'

# 图片下载错误。
FAILEDOPERATION_IMAGEDOWNLOADERROR = 'FailedOperation.ImageDownloadError'

# 人脸检测失败。
FAILEDOPERATION_IMAGEFACEDETECTFAILED = 'FailedOperation.ImageFacedetectFailed'

# 图片不存在前景。
FAILEDOPERATION_IMAGENOTFOREGROUND = 'FailedOperation.ImageNotForeground'

# 不支持的图片文件。
FAILEDOPERATION_IMAGENOTSUPPORTED = 'FailedOperation.ImageNotSupported'

# 图片分辨率过大。
FAILEDOPERATION_IMAGERESOLUTIONEXCEED = 'FailedOperation.ImageResolutionExceed'

# 图片分辨率过小。
FAILEDOPERATION_IMAGERESOLUTIONINSUFFICIENT = 'FailedOperation.ImageResolutionInsufficient'

# base64编码后的图片数据过大。
FAILEDOPERATION_IMAGESIZEEXCEED = 'FailedOperation.ImageSizeExceed'

# 服务内部错误，请重试。
FAILEDOPERATION_INNERERROR = 'FailedOperation.InnerError'

# 任务冲突。
FAILEDOPERATION_JOBCONFLICT = 'FailedOperation.JobConflict'

# 任务队列已满。
FAILEDOPERATION_JOBQUEUEFULL = 'FailedOperation.JobQueueFull'

# 图片中没有人体。
FAILEDOPERATION_NOBODYINPHOTO = 'FailedOperation.NoBodyInPhoto'

# 人像数过多。
FAILEDOPERATION_PROFILENUMEXCEED = 'FailedOperation.ProfileNumExceed'

# 整个请求体太大（通常主要是图片）。
FAILEDOPERATION_REQUESTENTITYTOOLARGE = 'FailedOperation.RequestEntityTooLarge'

# 请求的次数超过了频率限制。
FAILEDOPERATION_REQUESTLIMITEXCEEDED = 'FailedOperation.RequestLimitExceeded'

# 后端服务超时。
FAILEDOPERATION_REQUESTTIMEOUT = 'FailedOperation.RequestTimeout'

# RPC请求失败，一般为算法微服务故障。
FAILEDOPERATION_RPCFAIL = 'FailedOperation.RpcFail'

# 人像分割失败。
FAILEDOPERATION_SEGMENTFAILED = 'FailedOperation.SegmentFailed'

# 算法服务异常，请重试。
FAILEDOPERATION_SERVERERROR = 'FailedOperation.ServerError'

# 任务超过上限。
FAILEDOPERATION_TASKLIMITEXCEEDED = 'FailedOperation.TaskLimitExceeded'

# 任务不存在。
FAILEDOPERATION_TASKNOTEXIST = 'FailedOperation.TaskNotExist'

# 任务取消失败。
FAILEDOPERATION_TERMINATETASKFAILED = 'FailedOperation.TerminateTaskFailed'

# 文件太大。
FAILEDOPERATION_TOOLARGEFILEERROR = 'FailedOperation.TooLargeFileError'

# 内部错误。
FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnKnowError'

# 未知错误。
FAILEDOPERATION_UNKNOWN = 'FailedOperation.Unknown'

# 视频解码失败。
FAILEDOPERATION_VIDEODECODEFAILED = 'FailedOperation.VideoDecodeFailed'

# 参数不合法。
INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'

# 账号人体动作轨迹数量超出限制。
INVALIDPARAMETERVALUE_ACCOUNTTRACENUMEXCEED = 'InvalidParameterValue.AccountTraceNumExceed'

# 算法模型版本不合法。
INVALIDPARAMETERVALUE_BODYMODELVERSIONILLEGAL = 'InvalidParameterValue.BodyModelVersionIllegal'

# 传入的人体框过多。
INVALIDPARAMETERVALUE_BODYRECTSEXCEED = 'InvalidParameterValue.BodyRectsExceed'

# 人体库ID已经存在。人体库ID不可重复。
INVALIDPARAMETERVALUE_GROUPIDALREADYEXIST = 'InvalidParameterValue.GroupIdAlreadyExist'

# 人体库ID包含非法字符。人体库ID只支持英文、数字、-%@#&_。
INVALIDPARAMETERVALUE_GROUPIDILLEGAL = 'InvalidParameterValue.GroupIdIllegal'

# 人体库ID不存在。
INVALIDPARAMETERVALUE_GROUPIDNOTEXIST = 'InvalidParameterValue.GroupIdNotExist'

# 人体库ID超出长度限制。
INVALIDPARAMETERVALUE_GROUPIDTOOLONG = 'InvalidParameterValue.GroupIdTooLong'

# 人体库名称已经存在。人体库名称不可重复。
INVALIDPARAMETERVALUE_GROUPNAMEALREADYEXIST = 'InvalidParameterValue.GroupNameAlreadyExist'

# 人体库名称超出长度限制。
INVALIDPARAMETERVALUE_GROUPNAMETOOLONG = 'InvalidParameterValue.GroupNameTooLong'

# 人体库数量超出限制。
INVALIDPARAMETERVALUE_GROUPNUMEXCEED = 'InvalidParameterValue.GroupNumExceed'

# 人体库备注超出长度限制。
INVALIDPARAMETERVALUE_GROUPTAGTOOLONG = 'InvalidParameterValue.GroupTagTooLong'

# 人体库人体动作轨迹数量超出限制。
INVALIDPARAMETERVALUE_GROUPTRACENUMEXCEED = 'InvalidParameterValue.GroupTraceNumExceed'

# 图片为空。
INVALIDPARAMETERVALUE_IMAGEEMPTY = 'InvalidParameterValue.ImageEmpty'

# 返回数量不在合法范围内。
INVALIDPARAMETERVALUE_LIMITEXCEED = 'InvalidParameterValue.LimitExceed'

# 图片中没有人脸。
INVALIDPARAMETERVALUE_NOFACEINPHOTO = 'InvalidParameterValue.NoFaceInPhoto'

# 起始序号过大。请检查需要请求的数组长度。
INVALIDPARAMETERVALUE_OFFSETEXCEED = 'InvalidParameterValue.OffsetExceed'

# 人员ID已经存在。人员ID不可重复。
INVALIDPARAMETERVALUE_PERSONIDALREADYEXIST = 'InvalidParameterValue.PersonIdAlreadyExist'

# 人员ID包含非法字符。人员ID只支持英文、数字、-%@#&_。
INVALIDPARAMETERVALUE_PERSONIDILLEGAL = 'InvalidParameterValue.PersonIdIllegal'

# 人员ID不存在。
INVALIDPARAMETERVALUE_PERSONIDNOTEXIST = 'InvalidParameterValue.PersonIdNotExist'

# 人员ID超出长度限制。
INVALIDPARAMETERVALUE_PERSONIDTOOLONG = 'InvalidParameterValue.PersonIdTooLong'

# 人员名称包含非法字符。
INVALIDPARAMETERVALUE_PERSONNAMEILLEGAL = 'InvalidParameterValue.PersonNameIllegal'

# 人员名称超出长度限制。
INVALIDPARAMETERVALUE_PERSONNAMETOOLONG = 'InvalidParameterValue.PersonNameTooLong'

# 人员人体动作轨迹数量超出限制。
INVALIDPARAMETERVALUE_PERSONTRACENUMEXCEED = 'InvalidParameterValue.PersonTraceNumExceed'

# 搜索的人员数目超过限制。
INVALIDPARAMETERVALUE_SEARCHPERSONSEXCEED = 'InvalidParameterValue.SearchPersonsExceed'

# 创建人体动作轨迹的人体图片数量超出限制。
INVALIDPARAMETERVALUE_TRACEBODYNUMEXCEED = 'InvalidParameterValue.TraceBodyNumExceed'

# TraceMatchThreshold参数不合法。
INVALIDPARAMETERVALUE_TRACEMATCHTHRESHOLDILLEGAL = 'InvalidParameterValue.TraceMatchThresholdIllegal'

# URL格式不合法。
INVALIDPARAMETERVALUE_URLILLEGAL = 'InvalidParameterValue.UrlIllegal'

# 文件太大。
LIMITEXCEEDED_TOOLARGEFILEERROR = 'LimitExceeded.TooLargeFileError'

# 必选参数为空。
MISSINGPARAMETER_ERRORPARAMETEREMPTY = 'MissingParameter.ErrorParameterEmpty'

# 账号已欠费。
RESOURCEUNAVAILABLE_INARREARS = 'ResourceUnavailable.InArrears'

# 计费状态未知，请确认是否已在控制台开通服务。
RESOURCEUNAVAILABLE_NOTEXIST = 'ResourceUnavailable.NotExist'

# 服务未开通。
RESOURCEUNAVAILABLE_NOTREADY = 'ResourceUnavailable.NotReady'

# 未知方法名。
UNSUPPORTEDOPERATION_UNKNOWMETHOD = 'UnsupportedOperation.UnknowMethod'
